pub fn init_crypto_provider()Expand description
Installs the ring CryptoProvider as the process-wide rustls default.
Must be called once at application startup before any TLS connections are made.
pub fn init_crypto_provider()Installs the ring CryptoProvider as the process-wide rustls default.
Must be called once at application startup before any TLS connections are made.