pub struct DbIndexReader {
pool: SqlitePool,
dict_id: Option<i64>,
}Expand description
SQLite-backed implementation of IndexReader.
When dict_id is Some, queries are scoped to that dictionary.
When None, queries search across all indexed dictionaries.
Fields
pool: SqlitePooldict_id: Option<i64>Implementations
Sourceimpl DbIndexReader
impl DbIndexReader
Sourcepub fn new(database: &Database, dict_id: Option<i64>) -> Self
pub fn new(database: &Database, dict_id: Option<i64>) -> Self
Creates a new reader backed by database, optionally scoped to dict_id.
async fn exact_scoped(&self, headword: &str, id: i64) -> Vec<Entry>
async fn exact_global(&self, headword: &str) -> Vec<Entry>
async fn fuzzy_scoped( &self, headword: &str, prefix: &str, id: i64, ) -> Vec<Entry>
async fn fuzzy_global(&self, headword: &str, prefix: &str) -> Vec<Entry>
fn query_exact(&self, headword: &str) -> Vec<Entry>
fn query_fuzzy(&self, headword: &str) -> Vec<Entry>