load_dictionary

Function load_dictionary 

pub fn load_dictionary(
    content: Box<dyn DictReader>,
    index: Box<dyn IndexReader>,
) -> Dictionary
Load dictionary from given DictReader and Index.

A dictionary is made of an index and a dictionary (data). Both are required for look up. This function allows abstraction from the underlying source by only requiring a DictReader and an IndexReader.