pub enum EnsureAlarmOutcome {
Scheduled,
AlreadyScheduled,
PastDue,
}Expand description
The outcome of an AlarmManager::ensure_scheduled call.
Variants
Scheduled
No alarm of this type existed; one was freshly scheduled.
AlreadyScheduled
An alarm of this type already existed and its wake time is in the future.
PastDue
An alarm of this type existed but was past-due; it has been cancelled.
Only returned when PastDueAction::Cancel was requested. When
PastDueAction::Reschedule is requested the stale alarm is replaced
and EnsureAlarmOutcome::Scheduled is returned instead.