pub struct Settings {Show 36 fields
pub selected_library: usize,
pub keyboard_layout: String,
pub frontlight: bool,
pub wifi: bool,
pub inverted: bool,
pub sleep_cover: bool,
pub auto_share: bool,
pub auto_time: bool,
pub auto_frontlight: bool,
pub auto_frontlight_night_brightness: Option<LightLevel>,
pub auto_frontlight_manual_coordinates: Option<Coordinates>,
pub auto_frontlight_last_coordinates: Option<Coordinates>,
pub rotation_lock: Option<RotationLock>,
pub button_scheme: ButtonScheme,
pub auto_suspend: f32,
pub auto_power_off: f32,
pub time_format: String,
pub date_format: String,
pub external_urls_queue: Option<PathBuf>,
pub libraries: Vec<LibrarySettings>,
pub intermissions: Intermissions,
pub frontlight_presets: Vec<LightPreset>,
pub home: HomeSettings,
pub reader: ReaderSettings,
pub import: ImportSettings,
pub dictionary: DictionarySettings,
pub sketch: SketchSettings,
pub calculator: CalculatorSettings,
pub battery: BatterySettings,
pub frontlight_levels: LightLevels,
pub ota: OtaSettings,
pub logging: LoggingSettings,
pub settings_retention: usize,
pub db_backup_retention: usize,
pub startup_mode: StartupMode,
pub locale: Option<LanguageIdentifier>,
}Fields
selected_library: usizekeyboard_layout: Stringfrontlight: boolwifi: boolinverted: boolsleep_cover: boolauto_time: boolauto_frontlight: boolWhether frontlight levels should be managed automatically.
When enabled, Cadmus derives brightness and warmth from the current time and a known location.
auto_frontlight_night_brightness: Option<LightLevel>The brightness to use after sunset and before sunrise when automatic frontlight control is enabled.
auto_frontlight_manual_coordinates: Option<Coordinates>A user-specified location for automatic frontlight calculations.
When present, this takes precedence over coordinates discovered from automatic time syncing.
auto_frontlight_last_coordinates: Option<Coordinates>The last automatically discovered location for automatic frontlight calculations.
This is typically refreshed during automatic time synchronization and is used only when no manual coordinates are configured.
rotation_lock: Option<RotationLock>auto_suspend: f32auto_power_off: f32time_format: Stringdate_format: Stringexternal_urls_queue: Option<PathBuf>libraries: Vec<LibrarySettings>intermissions: Intermissionsfrontlight_presets: Vec<LightPreset>home: HomeSettingsreader: ReaderSettingsimport: ImportSettingsdictionary: DictionarySettingssketch: SketchSettingscalculator: CalculatorSettingsbattery: BatterySettingsfrontlight_levels: LightLevelsota: OtaSettingslogging: LoggingSettingssettings_retention: usizedb_backup_retention: usizestartup_mode: StartupModelocale: Option<LanguageIdentifier>Implementations