pub enum Category {
General,
Reader,
Libraries,
Intermissions,
Import,
Telemetry,
}Expand description
Categories of settings available in the settings editor.
Variants
General
General device settings (auto-suspend, keyboard layout, etc.)
Reader
Reader behavior settings (finished action, etc.)
Libraries
Library management settings
Intermissions
Intermission screen display settings
Import
Import behavior settings
Telemetry
Telemetry and logging settings
Implementations
Sourceimpl Category
impl Category
Sourcepub fn settings(&self, context: &Context) -> Vec<Box<dyn SettingKind>>
pub fn settings(&self, context: &Context) -> Vec<Box<dyn SettingKind>>
Returns the list of setting kinds for this category.
Each element is a heap-allocated SettingKind that fully describes
the label, current value, widget type, and tap event for one row.