pub struct CategoryButton {
id: Id,
rect: Rectangle,
children: Vec<Box<dyn View>>,
pub category: Category,
selected: bool,
align: Align,
}Expand description
A single category button that renders itself with background and text.
Similar to Directory widget in DirectoriesBar, this is a leaf node that handles its own rendering and touch events.
Fields
id: Idrect: Rectanglechildren: Vec<Box<dyn View>>category: Categoryselected: boolalign: AlignImplementations
Sourceimpl CategoryButton
impl CategoryButton
pub fn new( rect: Rectangle, category: Category, selected: bool, align: Align, ) -> CategoryButton
pub fn update_selected(&mut self, selected: bool)