CURRENT_DEVICE

Struct CURRENT_DEVICE 

pub struct CURRENT_DEVICE {
    __private_field: (),
}
Global singleton for the current device.

Fields

__private_field: ()

Methods from Deref<Target = Device>

pub fn metadata(&self) -> Result<&DeviceMetadata, DeviceError>

Gets device metadata (lazy initialization).

pub fn usb_manager(&self) -> Result<Box<dyn UsbManager>, UsbError>

Creates USB manager for this device.

pub fn wifi_manager(&self) -> Result<&dyn WifiManager, WifiError>

Returns the WiFi manager for this device.

pub fn color_samples(&self) -> usize

Returns the number of color samples for the device screen.

pub fn frontlight_kind(&self) -> FrontlightKind

Returns the frontlight kind for this device.

pub fn has_natural_light(&self) -> bool

Returns true if the device has natural light capability.

pub fn has_lightsensor(&self) -> bool

Returns true if the device has a light sensor.

pub fn has_gyroscope(&self) -> bool

Returns true if the device has a gyroscope.

pub fn has_page_turn_buttons(&self) -> bool

Returns true if the device has page turn buttons.

pub fn has_power_cover(&self) -> bool

Returns true if the device supports a power cover.

pub fn has_removable_storage(&self) -> bool

Returns true if the device has removable storage.

pub fn should_invert_buttons(&self, rotation: i8) -> bool

Returns true if buttons should be inverted for the given rotation.

pub fn orientation(&self, rotation: i8) -> Orientation

Returns the orientation for the given rotation.

pub fn mark(&self) -> u8

Returns the device mark value.

pub fn should_mirror_axes(&self, rotation: i8) -> (bool, bool)

Returns whether axes should be mirrored for the given rotation.

pub fn mirroring_scheme(&self) -> (i8, i8)

Returns the center and direction of the mirroring pattern.

pub fn should_swap_axes(&self, rotation: i8) -> bool

Returns true if axes should be swapped for the given rotation.

fn swapping_scheme(&self) -> i8

Returns the swapping scheme value.

pub fn startup_rotation(&self) -> i8

Returns the startup rotation value.

pub fn to_canonical(&self, n: i8) -> i8

Returns a device independent rotation value.

pub fn from_canonical(&self, n: i8) -> i8

Returns a device dependent rotation value from canonical.

pub fn transformed_rotation(&self, n: i8) -> i8

Returns the transformed rotation value.

pub fn transformed_gyroscope_rotation(&self, n: i8) -> i8

Returns the transformed gyroscope rotation value.