pub struct Device {
pub model: Model,
pub proto: TouchProto,
pub dims: (u32, u32),
pub dpi: u16,
metadata: OnceCell<DeviceMetadata>,
wifi_manager: OnceCell<Box<dyn WifiManager>>,
}Fields
model: Modelproto: TouchProtodims: (u32, u32)dpi: u16metadata: OnceCell<DeviceMetadata>wifi_manager: OnceCell<Box<dyn WifiManager>>Implementations
Sourceimpl Device
impl Device
Sourcefn new(product: &str, model_number: &str) -> Device
fn new(product: &str, model_number: &str) -> Device
Creates a new device from product and model number strings.
Sourcepub fn metadata(&self) -> Result<&DeviceMetadata, DeviceError>
pub fn metadata(&self) -> Result<&DeviceMetadata, DeviceError>
Gets device metadata (lazy initialization).
Sourcepub fn usb_manager(&self) -> Result<Box<dyn UsbManager>, UsbError>
pub fn usb_manager(&self) -> Result<Box<dyn UsbManager>, UsbError>
Creates USB manager for this device.
Sourcepub fn wifi_manager(&self) -> Result<&dyn WifiManager, WifiError>
pub fn wifi_manager(&self) -> Result<&dyn WifiManager, WifiError>
Returns the WiFi manager for this device.
Sourcepub fn color_samples(&self) -> usize
pub fn color_samples(&self) -> usize
Returns the number of color samples for the device screen.
Sourcepub fn frontlight_kind(&self) -> FrontlightKind
pub fn frontlight_kind(&self) -> FrontlightKind
Returns the frontlight kind for this device.
Sourcepub fn has_natural_light(&self) -> bool
pub fn has_natural_light(&self) -> bool
Returns true if the device has natural light capability.
Sourcepub fn has_lightsensor(&self) -> bool
pub fn has_lightsensor(&self) -> bool
Returns true if the device has a light sensor.
Sourcepub fn has_gyroscope(&self) -> bool
pub fn has_gyroscope(&self) -> bool
Returns true if the device has a gyroscope.
Returns true if the device has page turn buttons.
Sourcepub fn has_power_cover(&self) -> bool
pub fn has_power_cover(&self) -> bool
Returns true if the device supports a power cover.
Sourcepub fn has_removable_storage(&self) -> bool
pub fn has_removable_storage(&self) -> bool
Returns true if the device has removable storage.
Returns true if buttons should be inverted for the given rotation.
Sourcepub fn orientation(&self, rotation: i8) -> Orientation
pub fn orientation(&self, rotation: i8) -> Orientation
Returns the orientation for the given rotation.
Sourcepub fn should_mirror_axes(&self, rotation: i8) -> (bool, bool)
pub fn should_mirror_axes(&self, rotation: i8) -> (bool, bool)
Returns whether axes should be mirrored for the given rotation.
Sourcepub fn mirroring_scheme(&self) -> (i8, i8)
pub fn mirroring_scheme(&self) -> (i8, i8)
Returns the center and direction of the mirroring pattern.
Sourcepub fn should_swap_axes(&self, rotation: i8) -> bool
pub fn should_swap_axes(&self, rotation: i8) -> bool
Returns true if axes should be swapped for the given rotation.
Sourcefn swapping_scheme(&self) -> i8
fn swapping_scheme(&self) -> i8
Returns the swapping scheme value.
Sourcepub fn startup_rotation(&self) -> i8
pub fn startup_rotation(&self) -> i8
Returns the startup rotation value.
Sourcepub fn to_canonical(&self, n: i8) -> i8
pub fn to_canonical(&self, n: i8) -> i8
Returns a device independent rotation value.
Sourcepub fn from_canonical(&self, n: i8) -> i8
pub fn from_canonical(&self, n: i8) -> i8
Returns a device dependent rotation value from canonical.
Sourcepub fn transformed_rotation(&self, n: i8) -> i8
pub fn transformed_rotation(&self, n: i8) -> i8
Returns the transformed rotation value.
Sourcepub fn transformed_gyroscope_rotation(&self, n: i8) -> i8
pub fn transformed_gyroscope_rotation(&self, n: i8) -> i8
Returns the transformed gyroscope rotation value.