Event

Enum Event 

pub enum Event {
Show 82 variants Device(DeviceEvent), Gesture(GestureEvent), Keyboard(KeyboardEvent), Key(KeyKind), Open(Box<Info>), OpenHtml(String, Option<String>), LoadPixmap(usize), Update(UpdateMode), RefreshBookPreview(PathBuf), Invalid(PathBuf), Notification(NotificationEvent), Page(CycleDir), ResultsPage(CycleDir), GoTo(usize), GoToLocation(Location), ResultsGoTo(usize), CropMargins(Box<Margin>), Chapter(CycleDir), SelectDirectory(PathBuf), ToggleSelectDirectory(PathBuf), NavigationBarResized(i32), Focus(Option<ViewId>), Select(EntryId), PropagateSelect(EntryId), EditLanguages, Define(String), Submit(ViewId, String), Slider(SliderId, f32, FingerStatus), ToggleNear(ViewId, Rectangle), ToggleInputHistoryMenu(ViewId, Rectangle), ToggleBookMenu(Rectangle, usize), TogglePresetMenu(Rectangle, usize), SubMenu(Rectangle, Vec<EntryKind>), OpenSettingsCategory(Category), SelectSettingsCategory(Category), UpdateSettings(Box<Settings>), EditLibrary(usize), UpdateLibrary(usize, Box<LibrarySettings>), AddLibrary, DeleteLibrary(usize), ProcessLine(LineOrigin, String), History(CycleDir, bool), Toggle(ToggleEvent), Show(ViewId), Close(ViewId), CloseSub(ViewId), Search(String), SearchResult(usize, Vec<Boundary>), FetcherAddDocument(u32, Box<Info>), FetcherRemoveDocument(u32, PathBuf), FetcherSearch { id: u32, path: Option<PathBuf>, query: Option<String>, sort_by: Option<(SortMethod, bool)>, }, CheckFetcher(u32), EndOfSearch, Finished, ClockTick, BatteryTick, ToggleFrontlight, Load(PathBuf), LoadPreset(usize), Scroll(i32), Save, Guess, CheckBattery, SetWifi(bool), MightSuspend, PrepareSuspend, Suspend, Share, PrepareShare, Validate, Cancel, Reseed, Back, Quit, WakeUp, Hold(EntryId), FileChooserClosed(Option<PathBuf>), Github(GithubEvent), Settings(SettingsEvent), OpenNamedInput { view_id: ViewId, label: String, max_chars: usize, initial_text: String, }, OtaDownloadProgress { label: String, percent: u8, }, StartStableReleaseDownload,
}

Variants



Device(DeviceEvent)



Gesture(GestureEvent)



Keyboard(KeyboardEvent)



Key(KeyKind)



Open(Box<Info>)



OpenHtml(String, Option<String>)



LoadPixmap(usize)



Update(UpdateMode)



RefreshBookPreview(PathBuf)



Invalid(PathBuf)



Notification(NotificationEvent)



Page(CycleDir)



ResultsPage(CycleDir)



GoTo(usize)



GoToLocation(Location)



ResultsGoTo(usize)



CropMargins(Box<Margin>)



Chapter(CycleDir)



SelectDirectory(PathBuf)



ToggleSelectDirectory(PathBuf)



NavigationBarResized(i32)



Focus(Option<ViewId>)

Manages input focus state for focusable views like InputField.

This event controls which view currently receives keyboard input. It is not a navigation event — use Event::Show to transition between screens or display new UI components.

Variants

  • Focus(Some(view_id)) — Grants focus to the view matching view_id. The focused view will receive Event::Keyboard events. Parent views typically use this to show the on-screen keyboard.
  • Focus(None) — Clears focus from all views. Parent views typically use this to hide the on-screen keyboard.

Dispatch behavior

Focus events are broadcast: InputField returns false after handling this event so that all input fields in the hierarchy can update their focused/unfocused state.

Sending

Typically sent through the hub (hub.send(...)) by:

  • An InputField when tapped while unfocused
  • A parent view after building a screen that contains an input field
  • A keyboard’s hide method to clear focus

Example

use cadmus_core::view::{Event, ViewId};
use cadmus_core::view::ota::OtaViewId;

// Focus the PR input field (e.g. after building the PR input screen).
// Note: `hub` is provided by the application's event loop.
hub.send(Event::Focus(Some(ViewId::Ota(OtaViewId::PrInput)))).ok();

// Clear focus from all views.
hub.send(Event::Focus(None)).ok();


Select(EntryId)



PropagateSelect(EntryId)



EditLanguages



Define(String)



Submit(ViewId, String)



Slider(SliderId, f32, FingerStatus)



ToggleNear(ViewId, Rectangle)



ToggleInputHistoryMenu(ViewId, Rectangle)



ToggleBookMenu(Rectangle, usize)



TogglePresetMenu(Rectangle, usize)



SubMenu(Rectangle, Vec<EntryKind>)



OpenSettingsCategory(Category)



SelectSettingsCategory(Category)



UpdateSettings(Box<Settings>)



EditLibrary(usize)



UpdateLibrary(usize, Box<LibrarySettings>)



AddLibrary



DeleteLibrary(usize)



ProcessLine(LineOrigin, String)



History(CycleDir, bool)



Toggle(ToggleEvent)



Show(ViewId)



Close(ViewId)



CloseSub(ViewId)



Search(String)



SearchResult(usize, Vec<Boundary>)



FetcherAddDocument(u32, Box<Info>)



FetcherRemoveDocument(u32, PathBuf)



FetcherSearch

Fields

id: u32
sort_by: Option<(SortMethod, bool)>


CheckFetcher(u32)



EndOfSearch



Finished



ClockTick



BatteryTick



ToggleFrontlight



Load(PathBuf)



LoadPreset(usize)



Scroll(i32)



Save



Guess



CheckBattery



SetWifi(bool)



MightSuspend



PrepareSuspend



Suspend



Share



PrepareShare



Validate



Cancel



Reseed



Back



Quit



WakeUp



Hold(EntryId)



FileChooserClosed(Option<PathBuf>)

The file chooser was closed. The Option<PathBuf> contains the selected path, if any.



Github(GithubEvent)

GitHub authentication and API interaction events.



Settings(SettingsEvent)

Settings-specific events



OpenNamedInput

Request to open a NamedInput text overlay.

The handler is responsible for creating the overlay and placing it at the correct position in the view hierarchy so it sits at the top of the z-order.

Fields

view_id: ViewId

The ViewId used for both the overlay and the resulting Submit event.

label: String

Label text displayed inside the input dialog.

max_chars: usize

Maximum number of characters the input field accepts.

initial_text: String

Current value pre-populated into the input field.



OtaDownloadProgress

Progress update from a background OTA download thread.

OtaView handles this by updating the status label text and the progress bar fill to reflect the current download state.

Fields

label: String
percent: u8


StartStableReleaseDownload

Signal to start downloading the stable release after version check.

This event is sent from the version check thread when the remote version is newer than the current version, triggering the actual download to begin.